% Function to compute Arithmetic Asian Option price ; Vectorized version
%
% See article "Approaches to implementing Monte Carlo methods in MATLAB"
% by Sri Krishnamurthy,CFA and Jorge Paloschi,PHD
% in the September 2011 article of Wimott Magazine or at
% http://www.wilmott.com/magazine.cfm 
%
% Copyright 2011 MathWorks, Inc.
function [Price] = PriceArithmeticAsianOptionV(S0,X,r,T,sigma,NSteps,NPaths)
dt=T/NSteps;
nuT = (r - 0.5*sigma^2)*dt;
siT = sigma * sqrt(dt);

% Pre-allocate the grid
DiscPayoff=zeros(1,NPaths);

% Generate Random numbers beforehand
randNos = randn(NPaths,NSteps);

for i=1:NPaths
Path = S0.*cumprod(exp(nuT+siT*randNos(i,:)));
DiscPayoff(i) = exp(-r*T) .* max(sum(Path)./NSteps - X,0); 
end
Price = mean(DiscPayoff);
